##  Detailed Guides
Read through the detailed guide to learn how to use SAP LeanIX Technology Risk and Compliance for effective obsolescence risk management and technology standards management.
Guides | Description
---|---
[Obsolescence Risk Management Capabilities](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "An overview of features and capabilities of SAP LeanIX Technology Risk and Compliance to proactively identify, assess, and mitigate risks associated with outdated or unsupported technology across your IT landscape."):
  * [Technology Obsolescence Risk Statuses and Views in Reports](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how risk statuses are determined for IT components and applications and understand reporting views, such as Missing Data Percentage, Mitigated Risk Percentage, and Unaddressed Risk Percentage.")
  * [Obsolescence Risk Management Dashboard](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "Obsolescence risk management dashboard helps monitor unaddressed and addressed obsolescence risks, along with data completeness for comprehensive risk management.")
  * [Tutorial: Managing IT Risks Associated with Data Center and Server Locations](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations?locale=en-US&state=PRODUCTION&version=CLOUD "This is an example tutorial on managing the impact of data center and server location on risk mitigation and compliance using SAP LeanIX Technology Risk and Compliance.")

| Get an overview of obsolescence risk management capabilities provided by SAP LeanIX Technology Risk and Compliance.
[Technology Standards Management Capabilities](https://help.sap.com/docs/leanix/ea/technology-standards-management-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance facilitates inventorizing the technology landscape, provides comprehensive visibility, and helps you derive data-driven decisions to standardize the technology landscape.") | Get an overview of technology standards management capabilities provided by SAP LeanIX Technology Risk and Compliance.
[Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance enables you to automate the discovery of your self-built software by integrating this process into your developer toolchain."):
  * [GitHub Enterprise Integration](https://help.sap.com/docs/leanix/ea/github-enterprise-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Set up self-built software discovery using our out-of-the-box integration with GitHub Enterprise Server.")
  * [Microservice Discovery in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline?locale=en-US&state=PRODUCTION&version=CLOUD "Set up microservice discovery using a manifest file in your repository. This method, known as configuration-as-code, enables you to automatically discover microservices and update corresponding fact sheets in SAP LeanIX.")
  * [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom?locale=en-US&state=PRODUCTION&version=CLOUD "To understand and manage dependencies among your microservices, generate SBOM files and ingest them into SAP LeanIX using our API.")
  * [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover tech stacks from ingested SBOMs. Add custom tech stacks manually to complete your technology portfolio.")

| Learn how to set up automated discovery of microservices, import SBOM files, and view discovered technology stack.
[IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.") | Explore how to use best-practice reference data for IT components (including lifecycle information) and link catalog items to fact sheets.
[ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Fundamentals of the SAP LeanIX integration with ServiceNow \(CMDB\).") | Learn how to set up the integration with ServiceNow.
[Jira Service Management Integration](https://help.sap.com/docs/leanix/ea/jira-service-management-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Use the Jira Service Management integration to synchronize IT asset and application data between your configuration management database \(CMDB\) and SAP LeanIX.") | Learn how to set up the integration with Jira Service Management.
[Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&state=PRODUCTION&version=CLOUD "Learn why obsolescence risk management matters, how to discover risks associated with obsolete technology, how to assess their business impact, and how to efficiently manage and address them with SAP LeanIX.") | Follow our step-by-step tutorial to learn how to implement obsolescence risk management in SAP LeanIX.


